'==========================================
' Application Metering Script: counts the number of instances of a named application, 
' logs the data and sends an alert email if the count is over the specified application license count.
' This script is the combination of the following scripts located on this CD: 
' Tnames.vbs, processes.bat, runbatch.vbs, proccleanup.vbs, checkfile.vbs, and count-email.vbs. 
'==========================================


Option Explicit	
Const ForWriting = 2	
Const ForReading = 1	
Const ForAppending = 8	

' Get Terminal server computer list from AD terminal server OU
' Write terminal server names to terminalservers.txt

Dim objFSO 'File System Object
Dim objTSOU 'Terminal Server OU
Dim objTSItem 'Each item in OU
Dim strTSComputer 'Each terminal server
Dim strTSTextFolder 'folder to hold text file
Dim strTSTextFile 'list of terminal servers in the OU
Dim strTSLDAPPath 'Path to terminal server OU
Dim objTSTextFile 'created text file

' =====Configuration Area================
strTSTextFile = "terminalservers.txt"
strTSTextFolder = "\\ozark\it$\"
strTSLDAPPath = "LDAP://OU=ASH_TerminalServers, DC=alpineskihouse, DC=com"
' =====End Configuration Area============
 
Set objTSOU = GetObject(strTSLDAPPath)
objTSOU.Filter = Array("Computer")	

'=========================================
' If file exists add data, if not, then create file and add data

Set objFSO = CreateObject("Scripting.FileSystemObject")	

If objFSO.FileExists(strTSTextFolder & strTSTextFile) Then	
'do nothing	
Else	
Set objTSTextFile = objFSO.CreateTextFile(strTSTextFolder & strTSTextFile)		
objTSTextFile.Close	
End If 	

Set objTSTextFile = objFSO.OpenTextFile(strTSTextFolder & strTSTextFile, ForWriting)
For Each objTSItem in objTSOU
    strTSComputer = objTSItem.CN
    objTSTextFile.WriteLine strTSComputer
Next

objTSTextFile.Close

' ==========================================
' Delete all files in the directory

Dim strProcPath ' The directory path where the processes.txt lives
Dim objProcFolder ' Folder to store the processes.txt file
Dim objProcFolderCol 'All files in the folder
Dim objAnyTextFile 'Each file in the folder

' =====Configuration Area================
strProcPath = "\\ozark\it$\processes\"
' =====End Configuration Area============

Set objFSO = CreateObject("Scripting.FileSystemObject")         
Set objProcFolder = objFSO.GetFolder(strProcPath)

If objProcFolder.Files.count > 0 then
	Set objProcFolderCol = objProcFolder.Files
	For each objAnyTextFile in objProcFolderCol
	objAnyTextFile.Delete(True)
	Next
End if

Dim objBATfile ' Batch file location
Dim WSHShell 'Script shell to run batch file

' =====Configuration Area================
objBATFile = "\\ozark\it$\BAT\processes.bat"
' =====End Configuration Area============

Set WSHShell = CreateObject("Wscript.Shell")  
WSHShell.Run (objBATFile),0, True

' Remove the unneeded lines from the file

Dim strSearchString 'Each line in the file
Dim strNewContents ' New contents of processes.txt
Dim colMatches ' Collection of matches
Dim strMatch ' Each match
Dim objFindApp 'Regular Expression
Dim objProcessesFile ' path to processes.txt file
Dim objTextFile ' Open processes.txt file

' =====Configuration Area================
objProcessesFile = "\\ozark\it$\processes\processes.txt"
' =====End Configuration Area============

Set objFindApp = CreateObject("VBScript.RegExp")

' =====Configuration Area================
objFindApp.Pattern = "excel.exe"
' =====End Configuration Area============

Set objFSO = CreateObject("Scripting.FileSystemObject")
Set objTextFile = objFSO.OpenTextFile(objProcessesFile , ForReading)

Do Until objTextFile.AtEndOfStream
	strSearchString = objTextFile.ReadLine
	Set colMatches = objFindApp.Execute(strSearchString)  
	If colMatches.Count > 0 Then
		For Each strMatch in colMatches
		strNewContents = strNewContents & strSearchString & vbCrLf
		Next                      
	End If
Loop
objTextFile.Close

Set objTextFile = objFSO.OpenTextFile(objProcessesFile, ForWriting)
objTextFile.Write strNewContents
objTextFile.Close 

' Check to see if file is empty, then remove last carriage return

Dim strFileContents 'Contents of processes.txt
Dim intLength 'Length of contents
Dim strEndofString ' Last line in file

Set objFSO = CreateObject("Scripting.FileSystemObject")
Set objTextFile = objFSO.GetFile(objProcessesFile)
' WScript.Echo  "Size: " & objTextFile.Size
If objTextFile.Size > 0 Then 
	Set objTextFile = objFSO.OpenTextFile(objProcessesFile , ForReading)
	strFileContents = objTextFile.ReadAll
	objTextFile.Close
	intLength = Len(strFileContents)
	strEndofString = Right(strFileContents, 2)
		If strEndofString = vbCrLf Then
   		 strFileContents = Left(strFileContents, intLength - 2)
   		 Set objTextFile = objFSO.OpenTextFile(objProcessesFile, ForWriting)
  	 	 objTextFile.Write strFileContents
   		 objTextFile.Close
		End If
Else
    msgbox "There are no instances of the application running at this time." 
	wscript.quit
End If
'=========================================
'Check if processes.txt file exists in specified directory
				
	
' =====Configuration Area================	
objProcessesFile = "\\ozark\it$\processes\processes.txt"	
' =====End Configuration Area============	
	
Set objFSO = CreateObject("Scripting.FileSystemObject")	
	
If objFSO.FileExists(objProcessesFile) Then
	'do nothing	
Else	
	Wscript.Echo "Error - Processes file missing."
	WScript.Quit
End If 	

'=========================================	
'Count the lines in the file processes.txt	

Set objProcessesFile = objFSO.OpenTextFile(objProcessesFile, ForReading)	
objProcessesFile.ReadAll	

'=========================================
' If the count > licenses owned then email alert
	
Dim objLicensesOwned 'The number of application licenses owned	
	
' =====Configuration Area================	
objLicensesOwned = 1	
' =====End Configuration Area============	
	
' WScript.Echo objProcessesFile.line & " " & "objects still counted"	
If objProcessesFile.line > objLicensesOwned then	
	
' =====Configuration Area================	
Const strSMTPServer = "smtp.alpineskihouse.com"	
Const strFrom       = "alerts@alpineskihouse.com"	
Const strTo         = "techsupport@alpineskihouse.com"	
' =====End Configuration Area============		
	
Dim objMail               ' the CDO object	
Dim objWSHNetwork         ' windows-script-host network object	
Dim strNetBIOSComputer    ' the netbios name of our computer	
	
'=========================================
' get the NetBIOS computer name	
	
Set objWSHNetwork  = CreateObject ("WScript.Network")	
strNetBIOSComputer = objWSHNetwork.ComputerName	
Set objWSHNetwork  = Nothing 	
	
'=========================================
' do the real work to send the message 	
	
Set objMail = CreateObject ("CDO.Message")	
objMail.Configuration.Fields.Item ("http://schemas.microsoft.com/cdo/configuration/sendusing")      = 2	
objMail.Configuration.Fields.Item ("http://schemas.microsoft.com/cdo/configuration/smtpserver")     = strSMTPServer	
objMail.Configuration.Fields.Item ("http://schemas.microsoft.com/cdo/configuration/smtpserverport") = 25	
objMail.Configuration.Fields.Update	
objMail.From     = strFrom	
objMail.To       = strTo	
objMail.Subject = "Licensing Check!! " & Now	
objMail.Textbody = "Licensing Check!! "  & " The application count in use is " & objprocessesFile.line & " which is higher than number of licenses purchased " & Now	
objMail.Send	
Set objMail = Nothing	
                End if	
	
'=========================================
' Create or append data to log file	
					
Dim strProcLogDir ' Path to Reports folder	
Dim strProcLogFile ' Log file	
Dim objApp 'Specified application
Dim objProcLogFolder 'Processes Log Folder
Dim objProcLogFile 'Processes Log File	
Dim strProcLogText ' Text to write to Processes Log File
	
' =====Configuration Area================	
objApp = "excel.exe"	
strProcLogDir = "\\ozark\it$\reports"	
strProcLogFile = "\processcountlog.txt"	
' =====End Configuration Area============	
	
	Sub subAppend
	
	' Append count to the log file processcountlog.txt
	
	Set objProcLogFile = objFSO.OpenTextFile(strProcLogDir & strProcLogFile, ForAppending, true)		
	strProcLogText = NOW & " | The # of instances of " & objApp & " running is " & objProcessesFile.Line
	' Writes strText to processcountlog.txt
        objProcLogFile.WriteLine(strProcLogText)	
	objProcLogFile.close
	End Sub

'=========================================	
' Check that the directory folder exists, if not create file

If objFSO.FolderExists(strProcLogDir) Then	
'do nothing

Else	
   Set objProcLogFolder = objFSO.CreateFolder(strProcLogDir)	
objProcLogFolder.close
End If	

'=========================================
' If log file exists append data, if not, then create file and append data
	
If objFSO.FileExists(strProcLogDir & strProcLogFile) Then	
   call subAppend	
Else	
   Set objProcLogFile = objFSO.CreateTextFile(strProcLogDir & strProcLogFile)	
objProcLogFile.Close	
   call subAppend	
End If 	
	
WScript.Quit	

